@@ -398,6 +398,9 @@ void Init_curb_core() {
   CURB_DEFINE(CURLOPT_HEADER);
   CURB_DEFINE(CURLOPT_NOPROGRESS);
   CURB_DEFINE(CURLOPT_NOSIGNAL);
+#if HAVE_CURLOPT_PATH_AS_IS
+  CURB_DEFINE(CURLOPT_PATH_AS_IS);
+#endif
   CURB_DEFINE(CURLOPT_WRITEFUNCTION);
   CURB_DEFINE(CURLOPT_WRITEDATA);
   CURB_DEFINE(CURLOPT_READFUNCTION);
