@@ -79,9 +79,7 @@ void curl_multi_free(ruby_curl_multi *rbcm) {
     rbcm->requests = Qnil;
   }
 
-  if (rbcm->handle) {
-    curl_multi_cleanup(rbcm->handle);
-  }
+  curl_multi_cleanup(rbcm->handle);
   free(rbcm);
 }
 
@@ -194,13 +192,6 @@ static VALUE ruby_curl_multi_max_connects(VALUE self, VALUE count) {
 
   Data_Get_Struct(self, ruby_curl_multi, rbcm);
 
-  if (!rbcm->handle) {
-    rbcm->handle = curl_multi_init();
-    if (!rbcm->handle) {
-      rb_raise(mCurlErrFailedInit, "Failed to initialize multi handle");
-    }
-  }
-
   curl_multi_setopt(rbcm->handle, CURLMOPT_MAXCONNECTS, NUM2LONG(count));
 #endif
 
@@ -234,14 +225,6 @@ static VALUE ruby_curl_multi_pipeline(VALUE self, VALUE method) {
   } 
 
   Data_Get_Struct(self, ruby_curl_multi, rbcm);
-
-  if (!rbcm->handle) {
-    rbcm->handle = curl_multi_init();
-    if (!rbcm->handle) {
-      rb_raise(mCurlErrFailedInit, "Failed to initialize multi handle");
-    }
-  }
-
   curl_multi_setopt(rbcm->handle, CURLMOPT_PIPELINING, value);
 #endif
   return method == Qtrue ? 1 : 0;
@@ -274,13 +257,6 @@ VALUE ruby_curl_multi_add(VALUE self, VALUE easy) {
   /* setup the easy handle */
   ruby_curl_easy_setup( rbce );
 
-  if (!rbcm->handle) {
-    rbcm->handle = curl_multi_init();
-    if (!rbcm->handle) {
-      rb_raise(mCurlErrFailedInit, "Failed to initialize multi handle");
-    }
-  }
-
   mcode = curl_multi_add_handle(rbcm->handle, rbce->curl);
   if (mcode != CURLM_CALL_MULTI_PERFORM && mcode != CURLM_OK) {
     raise_curl_multi_error_exception(mcode);
@@ -319,13 +295,6 @@ VALUE ruby_curl_multi_remove(VALUE self, VALUE easy) {
 
   Data_Get_Struct(self, ruby_curl_multi, rbcm);
 
-  if (!rbcm->handle) {
-    rbcm->handle = curl_multi_init();
-    if (!rbcm->handle) {
-      rb_raise(mCurlErrFailedInit, "Failed to initialize multi handle");
-    }
-  }
-
   rb_curl_multi_remove(rbcm,easy);
 
   return self;
@@ -376,13 +345,6 @@ static VALUE ruby_curl_multi_cancel(VALUE self) {
   ruby_curl_multi *rbcm;
 
   Data_Get_Struct(self, ruby_curl_multi, rbcm);
-
-  if (!rbcm->handle) {
-    rbcm->handle = curl_multi_init();
-    if (!rbcm->handle) {
-      rb_raise(mCurlErrFailedInit, "Failed to initialize multi handle");
-    }
-  }
   
   rb_hash_foreach( rbcm->requests, ruby_curl_multi_cancel_callback, (VALUE)rbcm );
   
@@ -505,11 +467,10 @@ static void rb_curl_multi_run(VALUE self, CURLM *multi_handle, int *still_runnin
     mcode = curl_multi_perform(multi_handle, still_running);
   } while (mcode == CURLM_CALL_MULTI_PERFORM);
 
-
   if (mcode != CURLM_OK) {
     raise_curl_multi_error_exception(mcode);
   }
-
+  
 }
 
 #ifdef _WIN32
@@ -634,6 +595,15 @@ VALUE ruby_curl_multi_perform(int argc, VALUE *argv, VALUE self) {
         raise_curl_multi_error_exception(mcode);
       }
 
+      if (maxfd == -1) {
+        /* libcurl recommends sleeping for 100ms */
+        rb_thread_wait_for(rb_time_timeval(DBL2NUM(0.1)));
+        rb_curl_multi_run( self, rbcm->handle, &(rbcm->running) );
+        rb_curl_multi_read_info( self, rbcm->handle );
+        if (block != Qnil) { rb_funcall(block, rb_intern("call"), 1, self);  }
+        continue;
+      }
+
 #ifdef _WIN32
       create_crt_fd(&fdread, &crt_fdread);
       create_crt_fd(&fdwrite, &crt_fdwrite);
@@ -683,15 +653,7 @@ VALUE ruby_curl_multi_perform(int argc, VALUE *argv, VALUE self) {
 
   rb_curl_multi_read_info( self, rbcm->handle );
   if (block != Qnil) { rb_funcall(block, rb_intern("call"), 1, self);  }
-
-  /* do early cleanup */
-  VALUE hash = rbcm->requests;
-  if (!NIL_P(hash) && rb_type(hash) == T_HASH && RHASH_SIZE(hash) > 0) {
-    rb_hash_foreach(hash, curl_multi_flush_easy, (VALUE)rbcm);
-  }
-  curl_multi_cleanup(rbcm->handle);
-  rbcm->handle = NULL;
- 
+    
   return Qtrue;
 }
 
