@@ -18,7 +18,7 @@ rescue LoadError
 end
 require 'fileutils'
 
-$TEST_URL = "file://#{URI.escape(File.expand_path(__FILE__).tr('\\','/').tr(':','|'))}"
+$TEST_URL = "file://#{'/' if RUBY_DESCRIPTION =~ /mswin|msys|mingw|cygwin|bccwin|wince|emc/}#{URI.escape(File.expand_path(__FILE__).tr('\\','/'))}"
 
 require 'thread'
 require 'webrick'
@@ -52,13 +52,12 @@ class TestServlet < WEBrick::HTTPServlet::AbstractServlet
   end
 
   def self.port
-    (@port or 9129)
+    @port ||= 9129
   end
 
   def self.path
     '/methods'
   end
-
   def self.url
     "http://127.0.0.1:#{port}#{path}"
   end
@@ -70,12 +69,12 @@ class TestServlet < WEBrick::HTTPServlet::AbstractServlet
   end
 
   def do_GET(req,res)
-    if req.path.match /redirect$/
+    if req.path.match(/redirect$/)
       res.status = 302
       res['Location'] = '/foo'
-    elsif req.path.match /not_here$/
+    elsif req.path.match(/not_here$/)
       res.status = 404
-    elsif req.path.match /error$/
+    elsif req.path.match(/error$/)
       res.status = 500
     end
     respond_with("GET#{req.query_string}",req,res)
@@ -94,6 +93,9 @@ class TestServlet < WEBrick::HTTPServlet::AbstractServlet
       end
       if params and params['s'] == '500'
         res.status = 500
+      elsif params and params['c']
+        cookie = URI.decode_www_form(params['c'])[0][0].split('=')
+        res.cookies << WEBrick::Cookie.new(*cookie)
       else
         respond_with("POST\n#{req.body}",req,res)
       end
@@ -136,7 +138,7 @@ module TestServerMethods
 
   def server_setup(port=9129,servlet=TestServlet)
     @__port = port
-    if @server.nil? and !File.exist?(locked_file)
+    if (@server ||= nil).nil? and !File.exist?(locked_file)
 
       File.open(locked_file,'w') {|f| f << 'locked' }
       if TEST_SINGLE_THREADED
