@@ -5,7 +5,7 @@ end
 
 class TestCurbCurlEasy < Test::Unit::TestCase
   def test_global_reset
-    c = Curl.get($TEST_URL)
+    Curl.get($TEST_URL)
     # in a Timeout block you should reset the thread current handle 
     Curl.reset
   end
@@ -24,7 +24,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
       end
     end
 
-    t.each {|t| t.join }
+    t.each {|x| x.join }
   end
 
   def test_class_perform_01   
@@ -44,7 +44,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
   end    
 
   def test_class_perform_03
-    assert_raise(Curl::Err::CouldntReadError) { c = Curl::Easy.perform($TEST_URL + "nonexistent") }
+    assert_raise(Curl::Err::CouldntReadError) { Curl::Easy.perform($TEST_URL + "nonexistent") }
   end    
   
   def test_new_01
@@ -595,6 +595,15 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     assert_equal "some.file", c.cookiejar        
   end
 
+  def test_cookielist
+    c = Curl::Easy.new TestServlet.url
+    c.enable_cookies = true
+    c.post_body = URI.encode_www_form c: 'somename=somevalue'
+    assert_nil c.cookielist
+    c.perform
+    assert_match(/somevalue/, c.cookielist.join(''))
+  end
+
   def test_on_success
     curl = Curl::Easy.new($TEST_URL)    
     on_success_called = false
@@ -657,7 +666,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
       retries = 0
       begin
         count = 0
-        curl = Curl::Easy.send("http_#{method}", TestServlet.url) do|c|
+        Curl::Easy.send("http_#{method}", TestServlet.url) do|c|
           count += 1
           assert_equal Curl::Easy, c.class
         end
@@ -679,8 +688,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
       Curl::PostField.file('bar', File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown')))
     ]
     curl.http_post(fields)
-    assert_match /HTTP POST file upload/, curl.body_str
-    assert_match /Content-Disposition: form-data/, curl.body_str
+    assert_match(/HTTP POST file upload/, curl.body_str)
+    assert_match(/Content-Disposition: form-data/, curl.body_str)
   end
   
   def test_post_with_body_remote
@@ -706,8 +715,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     curl.multipart_form_post = true
     pf = Curl::PostField.file('readme', File.expand_path(File.join(File.dirname(__FILE__),'..','README.markdown')))
     curl.http_post(pf)
-    assert_match /HTTP POST file upload/, curl.body_str
-    assert_match /Content-Disposition: form-data/, curl.body_str
+    assert_match(/HTTP POST file upload/, curl.body_str)
+    assert_match(/Content-Disposition: form-data/, curl.body_str)
   end
 
   def test_delete_remote
@@ -729,7 +738,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     redirect = curl.header_str.match(/Location: (.*)/)
 
     assert_equal '', curl.body_str
-    assert_match '/nonexistent', redirect[1]
+    assert_match('/nonexistent', redirect[1])
   end
 
   def test_head_accessor
@@ -740,7 +749,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     redirect = curl.header_str.match(/Location: (.*)/)
 
     assert_equal '', curl.body_str
-    assert_match '/nonexistent', redirect[1]
+    assert_match('/nonexistent', redirect[1])
     curl.head = false
     curl.perform
     assert_equal 'GET', curl.body_str
@@ -750,11 +759,11 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     curl = Curl::Easy.new(TestServlet.url)
     curl.headers['Content-Type'] = 'application/json'
     assert curl.http_put("message")
-    assert_match /^PUT/, curl.body_str
-    assert_match /message$/, curl.body_str
-    assert_match /message$/, curl.body
-    assert_match /application\/json/, curl.header_str
-    assert_match /application\/json/, curl.head
+    assert_match(/^PUT/, curl.body_str)
+    assert_match(/message$/, curl.body_str)
+    assert_match(/message$/, curl.body)
+    assert_match(/application\/json/, curl.header_str)
+    assert_match(/application\/json/, curl.head)
   end 
   
   def test_put_data
@@ -763,8 +772,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     
     curl.perform
     
-    assert_match /^PUT/, curl.body_str
-    assert_match /message$/, curl.body_str
+    assert_match(/^PUT/, curl.body_str)
+    assert_match(/message$/, curl.body_str)
   end
 
   # https://github.com/taf2/curb/issues/101
@@ -774,8 +783,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
  
     curl.perform
     
-    assert_match /^PUT/, curl.body_str
-    assert_match "a\0b", curl.body_str
+    assert_match(/^PUT/, curl.body_str)
+    assert_match("a\0b", curl.body_str)
   end
 
   def test_put_nil_data_no_crash
@@ -790,7 +799,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     File.open(__FILE__,'rb') do|f|
       assert curl.http_put(f)
     end
-    assert_equal "PUT\n#{File.read(__FILE__)}", curl.body_str
+    assert_equal "PUT\n#{File.read(__FILE__)}", curl.body_str.tr("\r", '')
   end
   
   def test_put_class_method
@@ -800,7 +809,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
       assert_equal Curl::Easy, c.class
     end
     assert_equal 1, count
-    assert_equal "PUT\n#{File.read(__FILE__)}", curl.body_str
+    assert_equal "PUT\n#{File.read(__FILE__)}", curl.body_str.tr("\r", '')
   end
 
   # Generate a self-signed cert with
@@ -809,7 +818,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
   def test_cert
     curl = Curl::Easy.new(TestServlet.url)
     curl.cert= File.join(File.dirname(__FILE__),"cert.pem")
-    assert_match /cert.pem$/,curl.cert
+    assert_match(/cert.pem$/,curl.cert)
   end
 
   def test_cert_with_password
@@ -817,7 +826,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     path = File.join(File.dirname(__FILE__),"cert.pem")
     curl.certpassword = 'password'
     curl.cert = path
-    assert_match /cert.pem$/,curl.cert
+    assert_match(/cert.pem$/,curl.cert)
   end
 
   def test_cert_type
@@ -838,7 +847,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
   def test_ca_cert
     curl = Curl::Easy.new(TestServlet.url)
     curl.cacert= File.join(File.dirname(__FILE__),"cacert.pem")
-    assert_match /cacert.pem$/, curl.cacert
+    assert_match(/cacert.pem$/, curl.cacert)
   end
 
   def test_user_agent
@@ -896,7 +905,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     easy.http_post(pf)
 
     assert_not_equal(0,easy.body_str.size)
-    assert_equal(easy.body_str,File.read(readme))
+    assert_equal(easy.body_str.tr("\r", ''), File.read(readme))
   end
 
 
@@ -992,8 +1001,8 @@ class TestCurbCurlEasy < Test::Unit::TestCase
       curl.headers['Accept']         = '*/*'
       curl.headers['Authorization']  = 'Foo Bar Biz Baz'
       curl.http_put(rd)
-      assert_match /^PUT/, curl.body_str
-      assert_match /hello$/, curl.body_str
+      assert_match(/^PUT/, curl.body_str)
+      assert_match(/hello$/, curl.body_str)
       curl.header_str
       curl.body_str
     end
